{{ project_name }}
==================

This is the readme for your new Django project.
Fill it with thorough documentation.

License
-------

This project is under the {{ license }} license.
For details, check LICENSE.txt
